.. pspman documentation master file, created by
   sphinx-quickstart on Wed Jan 13 18:58:53 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##################################
Welcome to pspman's documentation!
##################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   name
   INSTALL
   usage
   source-code-doc


##################
Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
